/**
 * Sportmeetup FH Module
 */
var SPORTMEETUPFH = SPORTMEETUPFH || {};
SPORTMEETUPFH.Main = (function () {
	'use strict';

	/** Private */

	var path         = '/lv-moanw/initialprojekt/dev/public/'; // Without trailing slash
	var path         = '';
	var data         = null;
	var currentEvent = null;

	/**
	 * Load data via AJAX call
	 * and append to the view
	 */
	function loadData() {
		// Loading...

		$.get(path + '/', function(d) {
			data = d;
			
			$.each(data, function(key, value) {
				var $section = $( document.createElement('section') );
				var $header = $( document.createElement('header') );
				var $h1 = $( document.createElement('h1') );

				$h1.append(key);
				$header.append($h1);
				$section.append($header);

				$('#meetups').append($section);

				$.each(value, function(k, v) {
					var $div = $( document.createElement('div') );
					var $title = $( document.createElement('h2') );
					var $name = $( document.createElement('span') );
					
					$div.data('meetup-array-id', k);
					$div.data('meetup-date', v.date);
					$title.text(v.sport + ' um ' + v.time);
					$name.text('von ' + v.name);
					$div.append($title);
					$div.append($name);

					$div.bind('click', details);

					$section
						.append($div)
						.hide()
						.slideDown();
				});
			});

			// Loading done.
		});
	}

	/**
	 * Submit create a new meetup
	 */
	function createMeetup() {
		var valid = validateForm([
			$('#name').val(),
			$('#contact').val(),
			$('#sport').val(),
			$('#date').val(),
			$('#time-hour').val(),
			$('#time-minute').val(),
			$('#meetup-place').val()
		]);
		
		if (valid) {
			$.post(path + '/', {
				_token:      $('#_token').val(),
				name:        $('#name').val(),
				contact:     $('#contact').val(),
				sport:       $('#sport').val(),
				date:        $('#date').val(),
				time:        $('#time-hour').val() + ':' + $('#time-minute').val(),
				meetupPlace: $('#meetup-place').val()
			});

			$('#create')
				.find('input[type=text], textarea')
				.val('');

			/** Quick and Dirty Solution */
			$('#meetups').empty();
			loadData();
			$('#create-meetup').fadeOut();
			animTop();
		} else {
			alert('Bitte alle Felder ausfüllen!');
		}

		return false;
	}

	/**
	 * Details for a Meetup
	 * and possibility to attent
	 */
	function details() {
		currentEvent = data[ $(this).data('meetup-date') ][ $(this).data('meetup-array-id') ];

		/** Leider hier GET Request, schön wäre es gleich alle Daten mit einem Request zu laden */
		$.get(path + '/' + currentEvent.id + '/ps', function(d) {
			if (d.length == 0) {
				$('#no-ps').show();

				return false;
			};

			var num = 0;
			
			$.each(d, function(key, value) {
				num++;
				var $p = $( document.createElement('p') );

				$p.text(
					value.name 
					+ ' (' 
					+ value.contact
					+ ')'
				);
				$('#participants')
					.append($p)
					.hide()
					.slideDown();
			});
			
			$({ count: 0 }).animate({ 
				count: num
			}, {
				duration: 500,
				progress: function(animation, progress, remainingMs) {
					return $('.num').text( Math.floor( parseInt(this.count) * progress ) );
				}
			});
		});

		$('.sport').text(currentEvent.sport);
		$('.name').text(currentEvent.name);
		$('.date').text(currentEvent.date);
		$('.time').text(currentEvent.time);
		$('.contact').text(currentEvent.contact);
		$('.meeting-place').text(currentEvent.meeting_place);

		$('#create-meetup').fadeOut('slow');
		$('#meetups').fadeOut('slow', function() {
			$('#details').fadeIn('slow');
			animTop();
		});

		return false;
	}

	/**
	 * Submit form attend to a meetup
	 */
	function attendMeetup() {
		var valid = validateForm([
			$('#a-name').val(),
			$('#a-contact').val()
		]);
		if (valid) {
			$.post(path + '/' + currentEvent.id, {
				_token:  $('#_a-token').val(),
				id:      currentEvent.id,
				name:    $('#a-name').val(),
				contact: $('#a-contact').val()
			})

			$('#attend').fadeOut(function() {
				$('#attend')
					.find('input[type=text], textarea')
					.val('');
				
				animTop();
			});
			
			$('.success').fadeIn('slow');
		} else {
			alert('Bitte alle Felder ausfüllen!');
		}
		
		return false;
	}
	
	function validateForm(fields) {
		var isValid = true;
		
		$(fields).each(function(key, value) {
			if ( !$.trim(value) ) isValid = false;
		});
		
		return isValid;
	}
	
	/**
	 * Plus button at the top right corner
	 */
	function btnCreate() {
		$('#create-meetup').slideToggle();
	
		return false;
	}
	
	/**
	 * Info button at the top left corner 
	 */
	function btnInfo() {
		$('#info').slideToggle();
		
		return false;
	}

	/**
	 * Back button for attend view
	 */
	function btnBack() {
		$('#details').fadeOut('slow', function() {
			$('#meetups').fadeIn('slow');
			$('#attend').show();
			$('#participants').empty();
			$('#no-ps').hide();
			$('.success').hide();
			$('.num').text('0');
			animTop();
		});

		return false;
	}
	
	function featureDetection(element, attribute, value) {
		/** With Modernizr:
		Modernizr.inputtypes.date
		Modernizr.inputtypes.time */
		
		var el = document.createElement(element);
		el.setAttribute(attribute, value);
		
		return el.type == value;
	}
	
	/**
	 * Scroll to top animation
	 */
	function animTop() {
		$('html, body').animate({scrollTop: 0}, '500', 'swing');
		
		return false;
	}

	/** Public */

	return {
		/**
		 * Initialize
		 * Load data and call event listener setup
		 */
		init: function() {
			this.initDOM();

			loadData();

			this.initListeners();
		},

		/**
		 * Setup up event listeners
		 */
		initListeners: function() {
			$('#btnCreate').click(btnCreate);
			$('#btnInfo').click(btnInfo);
			$('#create').submit(createMeetup);
			$('#attend').submit(attendMeetup);
			$('.btn-back').bind('click', btnBack);
			$('[title="top"]').bind('click', animTop);
		},
		
		/**
		 * Hide and show different containers at startup
		 */
		initDOM: function() {
			$('#info').hide();
			$('#create-meetup').hide();
			$('#details').hide();
			$('#no-ps').hide();
			$('.success').hide();
			
			// var checkDate = featureDetection('input', 'type', 'date');
			// var checkTime = featureDetection('input', 'type', 'time');
			
			var today = new Date();

			var year = today.getFullYear();
			var month = today.getMonth() + 1;
			var date = today.getDate();

			for (var i = 0; i < 22; i++) {
				var next = new Date(year, month, date + i);
				var $option = $( document.createElement('option') );
				
				$option.append(
					next.getFullYear()
					+ '-' + ('0' + next.getMonth()).slice(-2)
					+ '-' + ('0' + next.getDate()).slice(-2)
				);
				
				$('#date').append($option);
			}
		}
	}
}());

/** On document ready... */
$(function() {
	$('html').removeClass('no-js');

	SPORTMEETUPFH.Main.init();
});
